@@ -10,7 +10,8 @@ from threading import Thread
 from typing import Optional, Union, List
 
 from .view import View
-from ...util import tensorneko_util_path, AbstractServer
+from ...util.server import AbstractServer
+from ...util import tensorneko_util_path
 
 
 class Server(AbstractServer):
@@ -72,6 +73,8 @@ class Server(AbstractServer):
         self.Handler = HTTPHandler
         self.Handler.extensions_map[".js"] = "application/javascript"
         self.Handler.extensions_map[".mjs"] = "application/javascript"
+        http.server.HTTPServer.allow_reuse_address = True
+        http.server.HTTPServer.allow_reuse_port = True
         Server.servers.append(self)
 
     def start(self) -> None:
